/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.osgi.debug.internal.osgi.commands;

import java.util.ArrayList;
import java.util.List;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.wiring.FrameworkWiring;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;

/**
 * @author Shuyang Zhou
 */
@Component(
	immediate = true,
	property = {"osgi.command.function=dc", "osgi.command.scope=system"},
	service = DependencyClosureOSGiCommands.class
)
public class DependencyClosureOSGiCommands {

	public void dc(long bundleId, long... additionalBundleIds) {
		List<Bundle> bundles = new ArrayList<>();

		bundles.add(_bundleContext.getBundle(bundleId));

		for (long additionalBundleId : additionalBundleIds) {
			bundles.add(_bundleContext.getBundle(additionalBundleId));
		}

		System.out.println(_frameworkWiring.getDependencyClosure(bundles));
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_bundleContext = bundleContext;

		Bundle systemBundle = bundleContext.getBundle(0);

		_frameworkWiring = systemBundle.adapt(FrameworkWiring.class);
	}

	private BundleContext _bundleContext;
	private FrameworkWiring _frameworkWiring;

}